Region enum
Values
- Indonesia → const Region
- Philippines → const Region
- Vietnam → const Region
- Malaysia → const Region
- Mexico → const Region
- Thailand → const Region
- Singapore → const Region
- Nigeria → const Region
- Pakistan → const Region
- Columbia → const Region
- Japan → const Region
- Taiwan → const Region
- HongKong → const Region
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited